==> kdepim-4.14.11_pre20160611.tar.xz: kdepim-4.14.11_pre20160611/kleopatra/uiserver/importfilescommand.cpp <==
/* -*- mode: c++; c-basic-offset:4 -*-
    uiserver/importfilescommand.cpp

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include <config-kleopatra.h>

#include "importfilescommand.h"

#include <commands/importcertificatefromfilecommand.h>

#include <kleo/exception.h>

#include <kde4_gpgme++/key.h>

#include <gpg-error.h>

#include <QStringList>

#include <string>
#include <algorithm>

using namespace Kleo;
using namespace boost;

class ImportFilesCommand::Private {
    friend class ::Kleo::ImportFilesCommand;
    ImportFilesCommand * const q;
public:
    Private( ImportFilesCommand * qq ) :
        q( qq ),
        command( 0 )
    {
        KDAB_SET_OBJECT_NAME( command );
        command.setAutoDelete( false );

        connect( &command, SIGNAL(finished()), q, SLOT(slotCommandFinished()) );
        connect( &command, SIGNAL(canceled()), q, SLOT(slotCommandCanceled()) );
    }

private:
    void slotCommandFinished() {
        q->done();
    }
    void slotCommandCanceled() {
        q->done( makeError( GPG_ERR_CANCELED ) );
    }

private:
    ImportCertificateFromFileCommand command;
};

ImportFilesCommand::ImportFilesCommand()
    : QObject(), AssuanCommandMixin<ImportFilesCommand>(), d( new Private( this ) ) {}

ImportFilesCommand::~ImportFilesCommand() {}

int ImportFilesCommand::doStart() {

    d->command.setParentWId( parentWId() );
    d->command.setFiles( fileNames() );
    d->command.start();

    return 0;
}

void ImportFilesCommand::doCanceled() {
    d->command.cancel();
}

#include "moc_importfilescommand.cpp"

==> kdepim-15.08.0.tar.xz: kdepim-15.08.0/kleopatra/uiserver/importfilescommand.cpp <==
/* -*- mode: c++; c-basic-offset:4 -*-
    uiserver/importfilescommand.cpp

    This file is part of Kleopatra, the KDE keymanager
    Copyright (c) 2008 Klarälvdalens Datakonsult AB

    Kleopatra is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Kleopatra is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

    In addition, as a special exception, the copyright holders give
    permission to link the code of this program with any edition of
    the Qt library by Trolltech AS, Norway (or with modified versions
    of Qt that use the same license as Qt), and distribute linked
    combinations including the two.  You must obey the GNU General
    Public License in all respects for all of the code used other than
    Qt.  If you modify this file, you may extend this exception to
    your version of the file, but you are not obligated to do so.  If
    you do not wish to do so, delete this exception statement from
    your version.
*/

#include <config-kleopatra.h>

#include "importfilescommand.h"

#include <commands/importcertificatefromfilecommand.h>

#include <kleo/exception.h>

#include <gpgme++/key.h>

#include <gpg-error.h>

#include <QStringList>

#include <string>
#include <algorithm>

using namespace Kleo;
using namespace boost;

class ImportFilesCommand::Private
{
    friend class ::Kleo::ImportFilesCommand;
    ImportFilesCommand *const q;
public:
    Private(ImportFilesCommand *qq) :
        q(qq),
        command(0)
    {
        KDAB_SET_OBJECT_NAME(command);
        command.setAutoDelete(false);

        connect(&command, SIGNAL(finished()), q, SLOT(slotCommandFinished()));
        connect(&command, SIGNAL(canceled()), q, SLOT(slotCommandCanceled()));
    }

private:
    void slotCommandFinished()
    {
        q->done();
    }
    void slotCommandCanceled()
    {
        q->done(makeError(GPG_ERR_CANCELED));
    }

private:
    ImportCertificateFromFileCommand command;
};

ImportFilesCommand::ImportFilesCommand()
    : QObject(), AssuanCommandMixin<ImportFilesCommand>(), d(new Private(this)) {}

ImportFilesCommand::~ImportFilesCommand() {}

int ImportFilesCommand::doStart()
{

    d->command.setParentWId(parentWId());
    d->command.setFiles(fileNames());
    d->command.start();

    return 0;
}

void ImportFilesCommand::doCanceled()
{
    d->command.cancel();
}

#include "moc_importfilescommand.cpp"
